pick_path_for_usages

Function pick_path_for_usages 

fn pick_path_for_usages<'a>(
    pattern: &'a ResolvedPattern<'_>,
) -> Option<&'a ResolvedPath>
Returns a path that’s suitable for path resolution. We exclude builtin types, since they aren’t something that we can find references to. We then somewhat arbitrarily pick the path that is the longest as this is hopefully more likely to be less common, making it faster to find.