pub(crate) struct UsageCache {
usages: Vec<(Definition, UsageSearchResult)>,
}Expand description
A cache for the results of find_usages. This is for when we have multiple patterns that have the
same path. e.g. if the pattern was foo::Bar that can parse as a path, an expression, a type
and as a pattern. In each, the usages of foo::Bar are the same and we’d like to avoid finding
them more than once.
Fields
usages: Vec<(Definition, UsageSearchResult)>Implementations
Sourceimpl UsageCache
impl UsageCache
fn find(&mut self, definition: &Definition) -> Option<&UsageSearchResult>